@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2016-01-21'; # DATE
-our $VERSION = '1.46'; # VERSION
+our $DATE = '2016-01-22'; # DATE
+our $VERSION = '1.47'; # VERSION
 
 use 5.010001;
 use strict;
@@ -986,6 +986,7 @@ sub __gen_iter {
             unless (defined $l) {
                 $eof++; return undef;
             }
+            chomp($l) unless $type eq 'buf';
             $l;
         };
     } else {
@@ -1411,7 +1412,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.46 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-01-21.
+This document describes version 1.47 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2016-01-22.
 
 =head1 DESCRIPTION
 
@@ -2220,7 +2221,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
 
 =head1 BUGS
 
